@@ -27,5 +27,9 @@ class CmdParser:
 
         args = parser.parse_args()
         args_dict = vars(args)
+
+        if len(args_dict) == 0:
+            print('Wrong usage')
+
         logger.debug(f'Received arguments: {args_dict}')
         return args_dict
